==> libreoffice-fresh-sdk-25.2.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.js <==
var servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle =
[
    [ "ParaUserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a6635b996396dc7acb2de112c80ca9d5b", null ],
    [ "ParagraphProperties", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2e6ac977c1a4ed634a3202bee12e7f3f", null ],
    [ "Style", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a5e9f1352d67bd8654859e234a2390c16", null ],
    [ "Category", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2131075d1cfb7b0b77af109bedcde640", null ],
    [ "CharDiffHeight", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a148e29ec49b1210715be23140caf623b", null ],
    [ "CharDiffHeightAsian", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ac85611faa04c73904ac1540f30e7aab4", null ],
    [ "CharDiffHeightComplex", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a95a3598f3f02671e4655f9e99e95965c", null ],
    [ "CharPropHeight", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a6ec9c780d8b00bcf0d30dc2c46e2676f", null ],
    [ "CharPropHeightAsian", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ac797243c59621c3996ee760499ff5773", null ],
    [ "CharPropHeightComplex", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a0962739a86dddb22218efd61a78b5b22", null ],
    [ "PageStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a37ddb97ccd5a589ce2cae9e3d60ec037", null ],
    [ "ParaBottomMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2d0beb3935e8c5c45eb842b1f65e08c8", null ],
    [ "ParaLeftMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ab6dcc1fa971ffb08d47765402d46c552", null ],
    [ "ParaRightMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a13cea00f0d3fa1e4c33a4966522f08fd", null ],
    [ "ParaTopMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a8f22a90cd9679edb943f5de3f534de33", null ]
];

==> libreoffice-fresh-sdk-25.8.4-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.js <==
var servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle =
[
    [ "com::sun::star::xml::ParaUserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a6635b996396dc7acb2de112c80ca9d5b", null ],
    [ "ParagraphProperties", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2e6ac977c1a4ed634a3202bee12e7f3f", null ],
    [ "Style", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a5e9f1352d67bd8654859e234a2390c16", null ],
    [ "Category", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2131075d1cfb7b0b77af109bedcde640", null ],
    [ "CharDiffHeight", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a148e29ec49b1210715be23140caf623b", null ],
    [ "CharDiffHeightAsian", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ac85611faa04c73904ac1540f30e7aab4", null ],
    [ "CharDiffHeightComplex", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a95a3598f3f02671e4655f9e99e95965c", null ],
    [ "CharPropHeight", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a6ec9c780d8b00bcf0d30dc2c46e2676f", null ],
    [ "CharPropHeightAsian", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ac797243c59621c3996ee760499ff5773", null ],
    [ "CharPropHeightComplex", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a0962739a86dddb22218efd61a78b5b22", null ],
    [ "PageStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a37ddb97ccd5a589ce2cae9e3d60ec037", null ],
    [ "ParaBottomMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a2d0beb3935e8c5c45eb842b1f65e08c8", null ],
    [ "ParaLeftMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#ab6dcc1fa971ffb08d47765402d46c552", null ],
    [ "ParaRightMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a13cea00f0d3fa1e4c33a4966522f08fd", null ],
    [ "ParaTopMarginRelative", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphStyle.html#a8f22a90cd9679edb943f5de3f534de33", null ]
];
